@@ -1,6 +1,10 @@
 package Devel::Optic::Lens::Perlish::Constants;
+$Devel::Optic::Lens::Perlish::Constants::VERSION = '0.011';
+# ABSTRACT: Useful constants for the Perlish lens
+
 use strict;
 use warnings;
+
 use Exporter qw(import);
 
 use constant {
@@ -44,11 +48,11 @@ __END__
 
 =head1 NAME
 
-Devel::Optic::Lens::Perlish::Constants
+Devel::Optic::Lens::Perlish::Constants - Useful constants for the Perlish lens
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 AUTHOR
 
